<?php
/*
* $Id: cm_pi_related_products.php
* $Loc: /includes/modules/content/product_info/
*
* Name: RelatedProducts
* Version: 7.5.7
* Release Date: 2024-10-22
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_pi_related_products extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_PI_RELATED_PRODUCTS_';

    public function __construct() {
      parent::__construct(__FILE__);
      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }

    function execute() {

      $orderBy = 'ORDER BY ';
      $orderBy .= (MODULE_CONTENT_PI_RELATED_PRODUCTS_RANDOMIZE == 'True') ? 'rand()' : 'prp.pop_order_id, prp.pop_id';
      $orderBy .= (MODULE_CONTENT_PI_RELATED_PRODUCTS_MAX_DISP > 0) ? ' LIMIT ' . MODULE_CONTENT_PI_RELATED_PRODUCTS_MAX_DISP : '';

      $optional_rel_prods = sprintf(<<<'EOSQL'
SELECT DISTINCT %s,
  IF(s.status, s.specials_new_products_price, NULL) AS specials_new_products_price,
  IF(s.status, s.specials_new_products_price, p.products_price) AS final_price, p.products_quantity AS in_stock, IF(s.status, 1, 0) AS is_special, prp.pop_products_id_slave
EOSQL
      , Product::COLUMNS);

      if (MODULE_CONTENT_PI_RELATED_PRODUCTS_SHOW_DESCRIPTION == 'True')
        $optional_rel_prods .= sprintf(<<<'EOSQL'
  , substring_index(pd.products_description, ' ', %s) AS products_description
EOSQL
      , MODULE_CONTENT_PI_RELATED_PRODUCTS_DESCRIPTION_LENGTH);

      $optional_rel_prods .= sprintf(<<<'EOSQL'
  FROM products_related_products prp, products p
    LEFT JOIN products_description pd ON pd.products_id = p.products_id
    LEFT JOIN specials s ON s.products_id = p.products_id
    LEFT JOIN (SELECT products_id, COUNT(*) AS attribute_count FROM products_attributes GROUP BY products_id) a ON p.products_id = a.products_id
  WHERE prp.pop_products_id_slave = p.products_id
    AND pd.products_id = p.products_id
    AND language_id = %s
    AND prp.pop_products_id_master = %s
    AND p.products_status='1' %s
EOSQL
      , (int)$_SESSION['languages_id']
      , (int)$_GET['products_id']
      , $orderBy);

      $optional_rel_prods_query = $GLOBALS['db']->query($optional_rel_prods);

      if (mysqli_num_rows($optional_rel_prods_query) > 0) {
        $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
        include 'includes/modules/content/cm_template.php';
      }
    }

    protected function get_parameters() {
      return [
        $this->config_key_base . 'VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '7.5.6',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_pi_related_products::readonly(',
        ],
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Related Products Module',
          'value' => 'True',
          'desc' => 'Should this module be shown on the product info page?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'REMOVE_DATA' => [
          'title' => 'Uninstall Removes Database entries',
          'value' => 'False',
          'desc' => 'Do you want to remove the related products database table when uninstall the module? All your existing product relations will be lost, use this option only it you are sure that you will not use related products any more.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '120',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        $this->config_key_base . 'SHOW_DESCRIPTION' => [
          'title' => 'Display Product Description',
          'value' => 'False',
          'desc' => 'Show Product Description.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'DESCRIPTION_LENGTH' => [
          'title' => 'Maximum Description length',
          'value' => '25',
          'desc' => 'The number of words of the Name to display.',
        ],
        $this->config_key_base . 'MAX_DISP' => [
          'title' => 'Define Number of Items to Display',
          'value' => '0',
          'desc' => 'Maximum number of Related Products to display. 0 is unlimited.',
        ],
        $this->config_key_base . 'RANDOMIZE' => [
          'title' => 'Use Random Display Order',
          'value' => 'False',
          'desc' => 'Adds random sort order to products displayed. Recommended if maximum number of products is set.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_MAX_ROW_LISTS_OPTIONS' => [
          'title' => 'Admin Display: Maximum Rows',
          'value' => '10',
          'desc' => 'Sets the maximum number of rows to display per page.',
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_MAX_NAME_LENGTH' => [
          'title' => 'Admin Display: Drop-Down List Maximum Length',
          'value' => '50',
          'desc' => 'Sets the maximum length (in characters) of product name displayed in drop-down lists. Enter "0" to set this option to false.',
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_MAX_DISPLAY_LENGTH' => [
          'title' => 'Admin Display: Display List Maximum Length',
          'value' => '50',
          'desc' => 'Sets the maximum length (in characters) of product name displayed in list. Enter "0" to set this option to false.',
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_USE_ID' => [
          'title' => 'Admin Display: Use Product Id (PRO only)',
          'value' => 'False',
          'desc' => 'Uses Product Id in lists. When Product Model or Name is also selected, Product Id is displayed first.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_USE_MODEL' => [
          'title' => 'Admin Display: Use Product Model',
          'value' => 'False',
          'desc' => 'Uses Product Model in lists. When Product Name or Id is also selected, Product Id is displayed first.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_USE_NAME' => [
          'title' => 'Admin Display: Use Product Name',
          'value' => 'True',
          'desc' => 'Uses Product Name in lists. When Product Model or Id is also selected, Product Id or Model is displayed first.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_MODEL_SEPARATOR' => [
          'title' => 'Admin Display: Combine Model and Name separator',
          'value' => ': ',
          'desc' => 'Enter the characters you would like to separate ID, Model and Name, when using 2 or 3. Leave empty if only using one.',
        ],
         'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_MENU_SORT_ORDER' => [
          'title' => 'Sort Order in Menus (PRO only)',
          'value' => 'Name',
          'desc' => 'How should the Products be sorted in the Drop Down Menus.',
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_INACTIVE_PRODUCTS' => [
          'title' => 'Admin Display: Show Out of Stock Products (PRO only)',
          'value' => 'True',
          'desc' => 'Show Out of Stock Products in the Products Drop Down Menus.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_CONFIRM_DELETE' => [
          'title' => 'Admin Function: Use Delete Confirmation',
          'value' => 'True',
          'desc' => 'When set to True, a confirmation box will pop-up when deleting an association. Set to False to Delete without confirmation.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        'MODULE_CONTENT_PI_ADMIN_RELATED_PRODUCTS_INSERT_AND_INHERIT' => [
          'title' => 'Admin Function: Combine Insert with Inherit',
          'value' => 'False',
          'desc' => 'When set to True, clicking on Inherit will also Insert the product association. When False, Inherit works as before.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
     ];
    }

    function install($parameter_key = null) {
      parent::install($parameter_key);
      $GLOBALS['db']->query( "CREATE TABLE IF NOT EXISTS products_related_products (pop_id int(11) not null auto_increment, pop_products_id_master int(11) not null default '0', pop_products_id_slave int(11) not null default '0', pop_order_id smallint(6) not null default '0', primary key  (pop_id))");
    }

    public function remove() {
      parent::remove();
      if ( defined('MODULE_CONTENT_PI_RELATED_PRODUCTS_REMOVE_DATA') && MODULE_CONTENT_PI_RELATED_PRODUCTS_REMOVE_DATA == 'True' ) {
        $GLOBALS['db']->query("DROP TABLE IF EXISTS products_related_products");
      }
    }

    public static function readonly($value) {
      return $value;
    }

  }
