<?php
/*
* $Id: cm_sc_related_products.php
* $Loc: /includes/modules/content/shopping_cart/
*
* Name: RelatedProducts
* Version: 7.5.7
* Release Date: 2024-10-22
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_sc_related_products extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_SC_RELATED_PRODUCTS_';

    public function __construct() {
      parent::__construct(__FILE__);
      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
    }

    function execute() {

      if ($_SESSION['cart']->count_contents() > 0) {
        $content_width = MODULE_CONTENT_SC_RELATED_PRODUCTS_CONTENT_WIDTH;
        $card_layout = IS_PRODUCT_PRODUCTS_DISPLAY_ROW;
        $ids_in_cart_list = implode( ',', array_map( 'Product::build_prid', explode( ',', $_SESSION['cart']->get_product_id_list() ) ));

        $orderBy = 'order by ';
        $orderBy .= (MODULE_CONTENT_SC_RELATED_PRODUCTS_RANDOMIZE == 'True')?'rand()':'pop_order_id, pop_id';
        $orderBy .= (MODULE_CONTENT_SC_RELATED_PRODUCTS_MAX_DISP > 0)?' limit ' . MODULE_CONTENT_SC_RELATED_PRODUCTS_MAX_DISP:'';

        $optional_rel_prods = sprintf(<<<'EOSQL'
SELECT DISTINCT %s,
  IF(s.status, s.specials_new_products_price, NULL) AS specials_new_products_price,
  IF(s.status, s.specials_new_products_price, p.products_price) AS final_price, p.products_quantity AS in_stock, IF(s.status, 1, 0) AS is_special, prp.pop_products_id_slave
                                                                                 
EOSQL
        , Product::COLUMNS);

        if (MODULE_CONTENT_SC_RELATED_PRODUCTS_SHOW_DESCRIPTION == 'True')
          $optional_rel_prods .= sprintf(<<<'EOSQL'
  , substring_index(pd.products_description, ' ', %s) AS products_description
EOSQL
        , MODULE_CONTENT_SC_RELATED_PRODUCTS_DESCRIPTION_LENGTH);

          $optional_rel_prods .= sprintf(<<<'EOSQL'
  FROM products_related_products prp, products p
    LEFT JOIN products_description pd ON pd.products_id = p.products_id
    LEFT JOIN specials s ON s.products_id = p.products_id
    LEFT JOIN (SELECT products_id, COUNT(*) AS attribute_count FROM products_attributes GROUP BY products_id) a ON p.products_id = a.products_id
  WHERE prp.pop_products_id_slave = p.products_id
    AND pd.products_id = p.products_id
    AND language_id = %s
    AND pop_products_id_master in (%s)
    AND products_status = '1' %s
EOSQL
          , (int)$_SESSION['languages_id']
          , $ids_in_cart_list
          , $orderBy);

        $optional_rel_prods_query = $GLOBALS['db']->query($optional_rel_prods);

        if (mysqli_num_rows($optional_rel_prods_query) > 0) {
          $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
          include 'includes/modules/content/cm_template.php';
        }
      }
    }

    protected function get_parameters() {
      return [
        $this->config_key_base . 'VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '7.5.6',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_sc_related_products::readonly(',
        ],
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Related Products Module',
          'value' => 'True',
          'desc' => 'Should this module be shown on the shopping cart page?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '1100',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        $this->config_key_base . 'SHOW_DESCRIPTION' => [
          'title' => 'Display Product Description',
          'value' => 'False',
          'desc' => 'Show Product Description.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'DESCRIPTION_LENGTH' => [
          'title' => 'Maximum Description length',
          'value' => '25',
          'desc' => 'The number of words of the Name to display.',
        ],
        $this->config_key_base . 'MAX_DISP' => [
          'title' => 'Define Number of Items to Display',
          'value' => '0',
          'desc' => 'Maximum number of Related Products to display. 0 is unlimited.',
        ],
        $this->config_key_base . 'RANDOMIZE' => [
          'title' => 'Use Random Display Order',
          'value' => 'False',
          'desc' => 'Adds random sort order to products displayed. Recommended if maximum number of products is set.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
     ];
    }

    public static function readonly($value) {
      return $value;
    }

  }
